==> prtg-xml-2.0.2-sources.jar: org/adeptnet/prtg/xml/ObjectFactory.java <==

package org.adeptnet.prtg.xml;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.adeptnet.prtg.xml package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Prtg_QNAME = new QName("urn:ietf:params:xml:ns:prtg-1.0", "prtg");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.adeptnet.prtg.xml
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Prtg }
     * 
     */
    public Prtg createPrtg() {
        return new Prtg();
    }

    /**
     * Create an instance of {@link ChannelType }
     * 
     */
    public ChannelType createChannelType() {
        return new ChannelType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Prtg }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:ietf:params:xml:ns:prtg-1.0", name = "prtg")
    public JAXBElement<Prtg> createPrtg(Prtg value) {
        return new JAXBElement<Prtg>(_Prtg_QNAME, Prtg.class, null, value);
    }

}

==> prtg-xml-3.0.0-sources.jar: org/adeptnet/prtg/xml/ObjectFactory.java <==

package org.adeptnet.prtg.xml;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.adeptnet.prtg.xml package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Prtg_QNAME = new QName("http://xml.adeptnet.org/prtg/prtg.xsd", "prtg");
    private final static QName _Consumer_QNAME = new QName("http://xml.adeptnet.org/prtg/prtg.xsd", "Consumer");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.adeptnet.prtg.xml
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Prtg }
     * 
     */
    public Prtg createPrtg() {
        return new Prtg();
    }

    /**
     * Create an instance of {@link ChannelType }
     * 
     */
    public ChannelType createChannelType() {
        return new ChannelType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Prtg }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://xml.adeptnet.org/prtg/prtg.xsd", name = "prtg")
    public JAXBElement<Prtg> createPrtg(Prtg value) {
        return new JAXBElement<Prtg>(_Prtg_QNAME, Prtg.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AbstractConsumerConfig }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://xml.adeptnet.org/prtg/prtg.xsd", name = "Consumer")
    public JAXBElement<AbstractConsumerConfig> createConsumer(AbstractConsumerConfig value) {
        return new JAXBElement<AbstractConsumerConfig>(_Consumer_QNAME, AbstractConsumerConfig.class, null, value);
    }

}
